@@ -35,6 +35,8 @@
 extern "C" {
 #endif
 
+#ifndef WITHOUT_NANA 
+
 /*
  * nana-config.h - the system wide configuration file; we put the ifndef
  *   around it to avoid the file 5 million times during a compile.
@@ -179,7 +181,7 @@ static volatile int _di_target;
 #elif DI_LEVEL == 0
 #define DSG(e,g) /* nothing */
 #else
-#error DI_LEVEL should be 0 or 1 or 2
+error DI_LEVEL should be 0 or 1 or 2
 #endif
 
 #define DS(e) DSG(e,DI_DEFAULT_GUARD)
@@ -229,6 +231,31 @@ static volatile int _di_target;
 #define DNGHP(e,g,h,p) \
   _DIGHPS((!(e)),g,h,p,"DN("#e")")
 
+#else /* defined(WITHOUT_NANA) */
+
+#define DI(e) /* empty */
+#define DIG(e,g) /* empty */
+#define DIH(e,h) /* empty */
+#define DIP(e,p) /* empty */
+#define DIGH(e,g,h) /* empty */
+#define DIGP(e,g,p) /* empty */
+#define DIHP(e,h,p) /* empty */
+#define DIGHP(e,g,h,p) /* empty */
+
+#define DN(e) /* empty */
+#define DNG(e,g) /* empty */
+#define DNH(e,h) /* empty */
+#define DNP(e,p) /* empty */
+#define DNGH(e,g,h) /* empty */
+#define DNGP(e,g,p) /* empty */
+#define DNHP(e,h,p) /* empty */
+#define DNGHP(e,g,h,p) /* empty */
+
+#define DS(e) /* empty */
+#define DSG(e,g) /* empty */
+
+
+#endif /* !defined(WITHOUT_NANA) */
 #ifdef __cplusplus
 }
 #endif
