@@ -35,6 +35,8 @@
 extern "C" {
 #endif
 
+#ifndef WITHOUT_NANA 
+
 /*
  * nana-config.h - the system wide configuration file; we put the ifndef
  *   around it to avoid the file 5 million times during a compile.
@@ -192,7 +194,6 @@ unsigned long _DL_gettime(void); /* returns the current time */
  *    varargs macros. if we are not using GNU C then they map to empty.
  */
 
-#ifdef __GNUC__ 
 #define VDL(a) DL a
 #define VDLG(a) DLG a
 #define VDLH(a) DLH a
@@ -200,7 +201,9 @@ unsigned long _DL_gettime(void); /* returns the current time */
 #define VDLGP(a) DLGP a
 #define VDLHP(a) DLHP a
 #define VDLGHP(a) DLGHP a
-#else
+
+#else /* defined(WITHOUT_NANA) */
+
 #define VDL(a) /* empty */
 #define VDLG(a) /* empty */
 #define VDLH(a) /* empty */
@@ -208,11 +211,10 @@ unsigned long _DL_gettime(void); /* returns the current time */
 #define VDLGP(a) /* empty */
 #define VDLHP(a) /* empty */
 #define VDLGHP(a) /* empty */
-#endif /* __GNUC__ */
+
+#endif /* !defined(WITHOUT_NANA) */
  
 
-
-
 #ifdef __cplusplus
 }
 #endif
