@@ -36,6 +36,8 @@
 extern "C" {
 #endif
 
+#ifndef WITHOUT_NANA
+
 /*
  * nana-config.h - the system wide configuration file; we put the ifndef
  *   around it to avoid the file 5 million times during a compile.
@@ -175,7 +177,6 @@ syntax error
  *    varargs macro. if we are not using GNU CC then they map to empty.
  */
 
-#ifdef __GNUC__ 
 #define VL(a) L a
 #define VLG(a) LG a
 #define VLH(a) LH a
@@ -183,7 +184,9 @@ syntax error
 #define VLGP(a) LGP a
 #define VLHP(a) LHP a
 #define VLGHP(a) LGHP a
-#else
+
+#else /* defined(WITHOUT_NANA) */
+
 #define VL(a) /* empty */
 #define VLG(a) /* empty */
 #define VLH(a) /* empty */
@@ -191,7 +194,8 @@ syntax error
 #define VLGP(a) /* empty */
 #define VLHP(a) /* empty */
 #define VLGHP(a) /* empty */
-#endif /* __GNUC__ */
+
+#endif /* !defined(WITHOUT_NANA) */
  
 #ifdef __cplusplus
 }
