@@ -25,7 +25,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: DL.c,v 1.3 1997/11/12 06:17:03 pjm Exp $
+ * $Id: DL.c,v 1.4 1997/11/13 21:22:34 pjm Exp $
  */
 
 
@@ -49,8 +49,6 @@ int main() {
      CHECKANSWER(DL("hello %d", 9+1),hello 10);
      CHECKANSWER(DL("hello %d %s",9+1,"x"),hello 10 x);
      CHECKANSWER(DL("hello %d\t%s",9+1,"x"),hello 10\tx);
-     CHECKANSWER(DL("%s hello %d\t%s", "hello ", 9+1,"x"),hello hello 10\tx);
-     CHECKANSWER(DL("%s hello %2.1f\t%s", "hello ", 3.0 + 0.1,"x"),hello hello 3.1\tx);
      
      DL_enabled = 0;
      CHECKEMPTY(DL("hello"));
